==> qtjambi-qt3dcore-5.15.13-sources.jar: io/qt/qt3d/core/QNodeDestroyedChange.java <==
package io.qt.qt3d.core;


/**
 * <p>Used to notify when a node is destroyed</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dcore-qnodedestroyedchange.html">Qt3DCore::QNodeDestroyedChange</a></p>
 */
public class QNodeDestroyedChange extends io.qt.qt3d.core.QSceneChange
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodedestroyedchange.html#QNodeDestroyedChange">Qt3DCore::QNodeDestroyedChange::QNodeDestroyedChange(const Qt3DCore::QNode*,QVector&lt;QNodeIdTypePair&gt;)</a></p>
     */
    @Deprecated
    public QNodeDestroyedChange(io.qt.qt3d.core.QNode node, java.util.Collection<? extends io.qt.qt3d.core.QNodeIdTypePair> subtreeIdsAndTypes){
        super((QPrivateConstructor)null);
        initialize_native(this, node, subtreeIdsAndTypes);
    }
    
    @Deprecated
    private native static void initialize_native(QNodeDestroyedChange instance, io.qt.qt3d.core.QNode node, java.util.Collection<? extends io.qt.qt3d.core.QNodeIdTypePair> subtreeIdsAndTypes);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodedestroyedchange.html#subtreeIdsAndTypes">Qt3DCore::QNodeDestroyedChange::subtreeIdsAndTypes()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.core.QNodeIdTypePair> subtreeIdsAndTypes(){
        return subtreeIdsAndTypes_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.core.QNodeIdTypePair> subtreeIdsAndTypes_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QNodeDestroyedChange(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-qt3dcore-5.15.14-sources.jar: io/qt/qt3d/core/QNodeDestroyedChange.java <==
package io.qt.qt3d.core;

import io.qt.*;


/**
 * <p>Used to notify when a node is destroyed</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dcore-qnodedestroyedchange.html">Qt3DCore::QNodeDestroyedChange</a></p>
 */
public class QNodeDestroyedChange extends io.qt.qt3d.core.QSceneChange
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodedestroyedchange.html#QNodeDestroyedChange">Qt3DCore::QNodeDestroyedChange::QNodeDestroyedChange(const Qt3DCore::QNode*,QVector&lt;Qt3DCore::QNodeIdTypePair&gt;)</a></p>
     */
    @Deprecated
    public QNodeDestroyedChange(io.qt.qt3d.core.@Nullable QNode node, java.util.@NonNull Collection<? extends io.qt.qt3d.core.@NonNull QNodeIdTypePair> subtreeIdsAndTypes){
        super((QPrivateConstructor)null);
        initialize_native(this, node, subtreeIdsAndTypes);
    }
    
    @Deprecated
    private native static void initialize_native(QNodeDestroyedChange instance, io.qt.qt3d.core.QNode node, java.util.Collection<? extends io.qt.qt3d.core.QNodeIdTypePair> subtreeIdsAndTypes);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodedestroyedchange.html#subtreeIdsAndTypes">Qt3DCore::QNodeDestroyedChange::subtreeIdsAndTypes()const</a></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QVector<io.qt.qt3d.core.@NonNull QNodeIdTypePair> subtreeIdsAndTypes(){
        return subtreeIdsAndTypes_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.core.QNodeIdTypePair> subtreeIdsAndTypes_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QNodeDestroyedChange(QPrivateConstructor p) { super(p); } 
    
}
